{% extends "../core/document.html" %}

{% comment ***************** %}
{% comment Emit content      %}
{% comment ***************** %}
{% block doc-content %}

	{% comment ************************************************** %}
	{% comment Sub-section: overview 		    				  %}
	{% comment ************************************************** %}
	<section>
		<header>
			<h3>Overview</h3>
		</header>
		<table>
			<tbody>
			{% set ctx = TemplateInfo(doc, fieldset='cim.1.activity.numericalexperiment-overview') %}
			{% include ../core/fieldset.html %}
			</tbody>
		</table>
	</section>

	{% comment ************************************************** %}
	{% comment Sub-section: requirements 		    			  %}
	{% comment ************************************************** %}
	{% if doc.requirements %}
		{% set header = 3 %}
		{% include activity_numerical_experiment_requirements.html %}
	{% end %}

{% end %}